@@ -126,6 +126,7 @@ def get_files(
     files: files.File | list[files.File] | None = None,
     formats: str | list[str] | None = None,
     glob_pattern: str | None = None,
+    exclude_pattern: str | None = None,
     on_the_fly: bool = False,
     **get_item_kwargs,
 ) -> list[files.File]:
@@ -139,6 +140,8 @@ def get_files(
 
     :param glob_pattern: Only return files matching the given glob pattern.
 
+    :param exclude_pattern: Exclude files matching the given glob pattern.
+
     :param on_the_fly: Include on-the-fly files (i.e. derivative EPUB,
                        MOBI, DAISY files).
 
@@ -153,7 +156,7 @@ def get_files(
         ['nasa_reviews.xml', 'nasa_meta.xml', 'nasa_files.xml']
     """
     item = get_item(identifier, **get_item_kwargs)
-    return item.get_files(files, formats, glob_pattern, on_the_fly)
+    return item.get_files(files, formats, glob_pattern, exclude_pattern, on_the_fly)
 
 
 def modify_metadata(
@@ -310,6 +313,7 @@ def download(
     on_the_fly: bool = False,
     return_responses: bool = False,
     no_change_timestamp: bool = False,
+    timeout: int | float | tuple[int, float] | None = None,
     **get_item_kwargs,
 ) -> list[requests.Request | requests.Response]:
     r"""Download files from an item.
@@ -372,6 +376,7 @@ def download(
         on_the_fly=on_the_fly,
         return_responses=return_responses,
         no_change_timestamp=no_change_timestamp,
+        timeout=timeout,
     )
     return r
 
@@ -460,7 +465,7 @@ def search_items(
     params: Mapping | None = None,
     full_text_search: bool = False,
     dsl_fts: bool = False,
-    archive_session: session.ArchiveSession = None,
+    archive_session: session.ArchiveSession | None = None,
     config: Mapping | None = None,
     config_file: str | None = None,
     http_adapter_kwargs: MutableMapping | None = None,
@@ -528,7 +533,7 @@ def configure(  # nosec: hardcoded_password_default
     username: str = "",
     password: str = "",
     config_file: str = "",
-    host: str = "",
+    host: str = "archive.org",
 ) -> str:
     """Configure internetarchive with your Archive.org credentials.
 
